==> rock-master-20.01-tools-smurf_0.20180405.orig.tar.gz: rock-master-20.01-tools-smurf_0.20180405/src/TranslationalJoint.hpp <==
#ifndef TRANSATIONALJOINT_H
#define TRANSATIONALJOINT_H

#include "Joint.hpp"

namespace smurf{
    
    class TranslationalJoint : public Joint
    {
    public:
        TranslationalJoint(const std::string &name, smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d &translationAxis);
        
        TranslationalJoint(const std::string &name, smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d& translationAxis, const Eigen::Affine3d& parentToJointOrigin, urdf::JointSharedPtr jointModel);
        
        TranslationalJoint(smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d &translationAxis);
        
        TranslationalJoint(smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d& translationAxis, const Eigen::Affine3d& parentToJointOrigin, urdf::JointSharedPtr jointModel);
        
        /**
         * Sliding axis of the joint in the target frame.
         * */
        Eigen::Vector3d translationAxis;
    };
    
};

#endif // TRANSATIONALJOINT_H

==> rock-master-22.06-tools-smurf_0.20220420.orig.tar.gz: rock-master-22.06-tools-smurf_0.20220420/src/TranslationalJoint.hpp <==
#ifndef TRANSATIONALJOINT_H
#define TRANSATIONALJOINT_H

#include "Joint.hpp"

namespace smurf{
    
    class TranslationalJoint : public Joint
    {
    public:
        TranslationalJoint(const std::string &name, smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d &translationAxis);
        
        TranslationalJoint(const std::string &name, smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d& translationAxis, const Eigen::Affine3d& parentToJointOrigin, urdf::JointSharedPtr jointModel);
        
        TranslationalJoint(const std::string &name, smurf::Frame* sourceFrame, smurf::Frame* targetFrame, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d& translationAxis, const Eigen::Affine3d& parentToJointOrigin, urdf::JointSharedPtr jointModel);
        
        TranslationalJoint(smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d &translationAxis);
        
        TranslationalJoint(smurf::Frame* sourceFrame, smurf::Frame* targetFrame, const std::string& provider, const std::string& port, const std::string& driverName, base::JointLimitRange& limits, const Eigen::Affine3d& sourceToAxis, const Eigen::Vector3d& translationAxis, const Eigen::Affine3d& parentToJointOrigin, urdf::JointSharedPtr jointModel);
        
        /**
         * Sliding axis of the joint in the target frame.
         * */
        Eigen::Vector3d translationAxis;
    };
    
};

#endif // TRANSATIONALJOINT_H
